@echo off
setlocal EnableDelayedExpansion
title StreamTUIT Credential Manager
color 1F

:: Clear screen and show header
cls
echo ================================================================
echo                 StreamTUIT Credential Manager
echo ================================================================
echo.

:: Check if credentials already exist and ask for confirmation
echo Checking for existing credentials...

:: Create a temporary file to store cmdkey output
set "tempFile=%TEMP%\credcheck.tmp"
cmdkey /list:cloud.streamtuit.com > "%tempFile%" 2>&1

:: Search for specific text that indicates real credentials exist
findstr /C:"Target: cloud.streamtuit.com" "%tempFile%" >NUL
set "credsExist=%ERRORLEVEL%"

:: Clean up temp file
del "%tempFile%" >NUL 2>&1

:: If credsExist is 0, it means credentials were found
if %credsExist% EQU 0 (
    echo Existing credentials for StreamTUIT found.
    choice /c YN /m "Do you want to overwrite them? " /t 60 /d N
    if !ERRORLEVEL! EQU 2 (
        echo.
        echo Operation canceled. Existing credentials will be kept.
        echo.
        pause
        goto :EOF
    )
    
    echo.
    echo Preparing for new credentials...
    cmdkey /delete:cloud.streamtuit.com >NUL 2>&1
    if %ERRORLEVEL% NEQ 0 (
        echo Warning: Could not delete existing credentials. Error code: %ERRORLEVEL%
        echo Continuing with credential creation anyway...
    )
) else (
    echo No existing credentials found. Proceeding with setup...
)

:GET_CREDENTIALS
echo.
echo ---------------------- User Authentication ----------------------
echo.
set "userinput="
echo Please enter your StreamTUIT username:
choice /c:\ /n /m "" /t 60 /d \ >NUL 2>&1
if %ERRORLEVEL% EQU 2 (
    echo Timeout reached. Operation canceled.
    goto :CLEANUP
)
set /p "userinput="
if "%userinput%"=="" (
    cls
    echo Username cannot be empty. Please try again.
    goto GET_CREDENTIALS
)

:GET_PASSWORDS
choice /c:\ /n /m "" /t 60 /d \ >NUL 2>&1
if %ERRORLEVEL% EQU 2 (
    echo Timeout reached. Operation canceled.
    goto :CLEANUP
)
set "password="
set "password2="
set "psCommand=powershell -Command "$pword = read-host 'Please enter your password' -AsSecureString ; ^
    $BSTR=[System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($pword); ^
        [System.Runtime.InteropServices.Marshal]::PtrToStringAuto($BSTR)""
for /f "usebackq delims=" %%p in (`%psCommand%`) do set password=%%p

if "%password%"=="" (
    cls
    echo Password cannot be empty. Please try again.
    goto GET_PASSWORDS
)

choice /c:\ /n /m "" /t 60 /d \ >NUL 2>&1
if %ERRORLEVEL% EQU 2 (
    echo Timeout reached. Operation canceled.
    goto :CLEANUP
)
set "psCommand=powershell -Command "$pword = read-host 'Please re-enter your password' -AsSecureString ; ^
    $BSTR=[System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($pword); ^
        [System.Runtime.InteropServices.Marshal]::PtrToStringAuto($BSTR)""
for /f "usebackq delims=" %%p in (`%psCommand%`) do set password2=%%p

if "%password2%"=="" (
    cls
    echo Password cannot be empty. Please try again.
    goto GET_PASSWORDS
)

IF "%password%"=="%password2%" GOTO MATCH

cls
echo Passwords do not match. Please try again.
goto GET_PASSWORDS

:MATCH
set "stusername=%userinput%"
echo %userinput% | findstr /C:"@streamtuit.com" >NUL
if errorlevel 1 set "stusername=%userinput%@streamtuit.com"

echo.
echo Processing your request...

:: Add credentials with error handling
cmdkey /add:cloud.streamtuit.com /user:%stusername% /pass:%password% >NUL 2>&1
if %ERRORLEVEL% NEQ 0 (
    cls
    echo Error: Failed to save credentials. Error code: %ERRORLEVEL%
    echo Please try again or contact IT support.
    goto :CLEANUP
)

:: Success message with fancy box
cls
echo ================================================================
echo                      OPERATION SUCCESSFUL
echo ================================================================
echo.
echo * Credentials saved successfully for: %stusername%
echo * You can now connect to StreamTUIT Cloud Services
echo.
echo Please test your connection to verify access.
echo.

:CLEANUP
:: Clear sensitive variables
set "credsExist="
set "userinput="
set "stusername="
set "password="
set "password2="
set "psCommand="

echo Press any key to exit.
pause >NUL
color 07
title Command Prompt
endlocal
goto :EOF